@@ -1,4 +1,3 @@
-# Udev::FFI::Devnum - Copyright (C) 2017-2019 Ilya Pavlov
 package Udev::FFI::Devnum;
 
 use strict;
@@ -9,7 +8,7 @@ our (@ISA, @EXPORT_OK, %EXPORT_TAGS);
 require Exporter;
 @ISA = qw(Exporter);
 
-@EXPORT_OK = qw(major minor makedev mkdev);
+@EXPORT_OK = qw(major minor makedev);
 
 %EXPORT_TAGS = (
     'all' => \@EXPORT_OK
@@ -34,13 +33,6 @@ sub makedev {
 
 
 
-sub mkdev { # 2017-12-19
-    warn "mkdev is deprecated, use makedev instead\n";
-    return makedev(@_);
-}
-
-
-
 1;
 
 
@@ -83,4 +75,4 @@ Return device number.
 
 L<Udev::FFI> main Udev::FFI documentation
 
-=cut
\ No newline at end of file
+=cut
